@@ -70,7 +70,8 @@ setMethodS3("callGNL", "PairedPSCBS", function(fit, flavor=c("TCN|AB"), ..., min
     calls[ns < minSize] <- NA;
     segs$ntcnCall <- calls;
     fit$output <- segs;
-    rm(segs, ns, calls); # Not needed anymore
+    # Not needed anymore
+    segs <- calls <- NULL;
   }
 
   return(invisible(fit));
